You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by or...@apache.org on 2024/03/21 22:08:04 UTC

(camel-spring-boot) branch main updated: (chores) camel-langchain: use a consistent project name

This is an automated email from the ASF dual-hosted git repository.

orpiske pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/camel-spring-boot.git


The following commit(s) were added to refs/heads/main by this push:
     new cc2851725de (chores) camel-langchain: use a consistent project name
cc2851725de is described below

commit cc2851725de88bb403a96e1b0438a796f40d0139
Author: Otavio Rodolfo Piske <an...@gmail.com>
AuthorDate: Thu Mar 21 21:18:00 2024 +0100

    (chores) camel-langchain: use a consistent project name
---
 .../catalog/components/langchain-chat.json         | 18 +++++++-------
 .../catalog/components/langchain-embeddings.json   | 22 ++++++++---------
 .../src/main/docs/langchain-chat.json              | 26 ++++++++++----------
 ...> LangChainChatComponentAutoConfiguration.java} | 16 ++++++-------
 ...va => LangChainChatComponentConfiguration.java} | 28 +++++++++++-----------
 ...r.java => LangChainChatComponentConverter.java} |  6 ++---
 ...rk.boot.autoconfigure.AutoConfiguration.imports |  2 ++
 .../src/main/docs/langchain-embeddings.json        | 20 ++++++++--------
 ...ChainEmbeddingsComponentAutoConfiguration.java} | 16 ++++++-------
 ...LangChainEmbeddingsComponentConfiguration.java} | 14 +++++------
 ... => LangChainEmbeddingsComponentConverter.java} |  6 ++---
 ...rk.boot.autoconfigure.AutoConfiguration.imports |  2 ++
 12 files changed, 90 insertions(+), 86 deletions(-)

diff --git a/catalog/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/langchain-chat.json b/catalog/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/langchain-chat.json
index e8eddae657b..0818c3da384 100644
--- a/catalog/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/langchain-chat.json
+++ b/catalog/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/langchain-chat.json
@@ -2,12 +2,12 @@
   "component": {
     "kind": "component",
     "name": "langchain-chat",
-    "title": "langchain 4j chat",
-    "description": "Langchain4j Chat component",
+    "title": "langChain4j Chat",
+    "description": "LangChain4j Chat component",
     "deprecated": false,
     "firstVersion": "4.5.0",
     "label": "ai",
-    "javaType": "org.apache.camel.component.chat.LangchainChatComponent",
+    "javaType": "org.apache.camel.component.chat.LangChainChatComponent",
     "supportLevel": "Preview",
     "groupId": "org.apache.camel.springboot",
     "artifactId": "camel-langchain-chat-starter",
@@ -23,19 +23,19 @@
     "remote": true
   },
   "componentProperties": {
-    "chatOperation": { "index": 0, "kind": "property", "displayName": "Chat Operation", "group": "producer", "label": "", "required": true, "type": "object", "javaType": "org.apache.camel.component.chat.LangchainChatOperations", "enum": [ "CHAT_SINGLE_MESSAGE", "CHAT_SINGLE_MESSAGE_WITH_PROMPT", "CHAT_MULTIPLE_MESSAGES" ], "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "defaultValue": "CHAT_SINGLE_MESSAGE", "configurationClass": "org.apache.camel.compone [...]
-    "configuration": { "index": 1, "kind": "property", "displayName": "Configuration", "group": "producer", "label": "", "required": false, "type": "object", "javaType": "org.apache.camel.component.chat.LangchainChatConfiguration", "deprecated": false, "autowired": false, "secret": false, "description": "The configuration." },
+    "chatOperation": { "index": 0, "kind": "property", "displayName": "Chat Operation", "group": "producer", "label": "", "required": true, "type": "object", "javaType": "org.apache.camel.component.chat.LangChainChatOperations", "enum": [ "CHAT_SINGLE_MESSAGE", "CHAT_SINGLE_MESSAGE_WITH_PROMPT", "CHAT_MULTIPLE_MESSAGES" ], "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "defaultValue": "CHAT_SINGLE_MESSAGE", "configurationClass": "org.apache.camel.compone [...]
+    "configuration": { "index": 1, "kind": "property", "displayName": "Configuration", "group": "producer", "label": "", "required": false, "type": "object", "javaType": "org.apache.camel.component.chat.LangChainChatConfiguration", "deprecated": false, "autowired": false, "secret": false, "description": "The configuration." },
     "lazyStartProducer": { "index": 2, "kind": "property", "displayName": "Lazy Start Producer", "group": "producer", "label": "producer", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": false, "description": "Whether the producer should be started lazy (on the first message). By starting lazy you can use this to allow CamelContext and routes to startup in situations where a producer may otherwise fail [...]
     "autowiredEnabled": { "index": 3, "kind": "property", "displayName": "Autowired Enabled", "group": "advanced", "label": "advanced", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": true, "description": "Whether autowiring is enabled. This is used for automatic autowiring options (the option must be marked as autowired) by looking up in the registry to find if there is a single instance of matching t [...]
-    "chatModel": { "index": 4, "kind": "property", "displayName": "Chat Model", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "dev.langchain4j.model.chat.ChatLanguageModel", "deprecated": false, "deprecationNote": "", "autowired": true, "secret": false, "configurationClass": "org.apache.camel.component.chat.LangchainChatConfiguration", "configurationField": "configuration", "description": "Chat Language Model of type dev.langchain4j.model.chat [...]
+    "chatModel": { "index": 4, "kind": "property", "displayName": "Chat Model", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "dev.langchain4j.model.chat.ChatLanguageModel", "deprecated": false, "deprecationNote": "", "autowired": true, "secret": false, "configurationClass": "org.apache.camel.component.chat.LangChainChatConfiguration", "configurationField": "configuration", "description": "Chat Language Model of type dev.langchain4j.model.chat [...]
   },
   "headers": {
-    "CamelLangchainChatPromptTemplate": { "index": 0, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The prompt Template.", "constantName": "org.apache.camel.component.chat.LangchainChat$Headers#PROMPT_TEMPLATE" }
+    "CamelLangChainChatPromptTemplate": { "index": 0, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The prompt Template.", "constantName": "org.apache.camel.component.chat.LangChainChat$Headers#PROMPT_TEMPLATE" }
   },
   "properties": {
     "chatId": { "index": 0, "kind": "path", "displayName": "Chat Id", "group": "producer", "label": "", "required": true, "type": "string", "javaType": "java.lang.String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The id" },
-    "chatOperation": { "index": 1, "kind": "parameter", "displayName": "Chat Operation", "group": "producer", "label": "", "required": true, "type": "object", "javaType": "org.apache.camel.component.chat.LangchainChatOperations", "enum": [ "CHAT_SINGLE_MESSAGE", "CHAT_SINGLE_MESSAGE_WITH_PROMPT", "CHAT_MULTIPLE_MESSAGES" ], "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "defaultValue": "CHAT_SINGLE_MESSAGE", "configurationClass": "org.apache.camel.compon [...]
+    "chatOperation": { "index": 1, "kind": "parameter", "displayName": "Chat Operation", "group": "producer", "label": "", "required": true, "type": "object", "javaType": "org.apache.camel.component.chat.LangChainChatOperations", "enum": [ "CHAT_SINGLE_MESSAGE", "CHAT_SINGLE_MESSAGE_WITH_PROMPT", "CHAT_MULTIPLE_MESSAGES" ], "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "defaultValue": "CHAT_SINGLE_MESSAGE", "configurationClass": "org.apache.camel.compon [...]
     "lazyStartProducer": { "index": 2, "kind": "parameter", "displayName": "Lazy Start Producer", "group": "producer (advanced)", "label": "producer,advanced", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": false, "description": "Whether the producer should be started lazy (on the first message). By starting lazy you can use this to allow CamelContext and routes to startup in situations where a produc [...]
-    "chatModel": { "index": 3, "kind": "parameter", "displayName": "Chat Model", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "dev.langchain4j.model.chat.ChatLanguageModel", "deprecated": false, "deprecationNote": "", "autowired": true, "secret": false, "configurationClass": "org.apache.camel.component.chat.LangchainChatConfiguration", "configurationField": "configuration", "description": "Chat Language Model of type dev.langchain4j.model.cha [...]
+    "chatModel": { "index": 3, "kind": "parameter", "displayName": "Chat Model", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "dev.langchain4j.model.chat.ChatLanguageModel", "deprecated": false, "deprecationNote": "", "autowired": true, "secret": false, "configurationClass": "org.apache.camel.component.chat.LangChainChatConfiguration", "configurationField": "configuration", "description": "Chat Language Model of type dev.langchain4j.model.cha [...]
   }
 }
diff --git a/catalog/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/langchain-embeddings.json b/catalog/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/langchain-embeddings.json
index a1359a7e935..536724ffee6 100644
--- a/catalog/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/langchain-embeddings.json
+++ b/catalog/camel-catalog-provider-springboot/src/main/resources/org/apache/camel/springboot/catalog/components/langchain-embeddings.json
@@ -2,12 +2,12 @@
   "component": {
     "kind": "component",
     "name": "langchain-embeddings",
-    "title": "Langchain4j Embeddings",
-    "description": "Langchain4j Embeddings",
+    "title": "LangChain4j Embeddings",
+    "description": "LangChain4j Embeddings",
     "deprecated": false,
     "firstVersion": "4.5.0",
     "label": "ai",
-    "javaType": "org.apache.camel.component.langchain.embeddings.LangchainEmbeddingsComponent",
+    "javaType": "org.apache.camel.component.langchain.embeddings.LangChainEmbeddingsComponent",
     "supportLevel": "Preview",
     "groupId": "org.apache.camel.springboot",
     "artifactId": "camel-langchain-embeddings-starter",
@@ -23,21 +23,21 @@
     "remote": true
   },
   "componentProperties": {
-    "configuration": { "index": 0, "kind": "property", "displayName": "Configuration", "group": "producer", "label": "", "required": false, "type": "object", "javaType": "org.apache.camel.component.langchain.embeddings.LangchainEmbeddingsConfiguration", "deprecated": false, "autowired": false, "secret": false, "description": "The configuration." },
-    "embeddingModel": { "index": 1, "kind": "property", "displayName": "Embedding Model", "group": "producer", "label": "", "required": true, "type": "object", "javaType": "dev.langchain4j.model.embedding.EmbeddingModel", "deprecated": false, "deprecationNote": "", "autowired": true, "secret": false, "configurationClass": "org.apache.camel.component.langchain.embeddings.LangchainEmbeddingsConfiguration", "configurationField": "configuration", "description": "The EmbeddingModel engine to  [...]
+    "configuration": { "index": 0, "kind": "property", "displayName": "Configuration", "group": "producer", "label": "", "required": false, "type": "object", "javaType": "org.apache.camel.component.langchain.embeddings.LangChainEmbeddingsConfiguration", "deprecated": false, "autowired": false, "secret": false, "description": "The configuration." },
+    "embeddingModel": { "index": 1, "kind": "property", "displayName": "Embedding Model", "group": "producer", "label": "", "required": true, "type": "object", "javaType": "dev.langchain4j.model.embedding.EmbeddingModel", "deprecated": false, "deprecationNote": "", "autowired": true, "secret": false, "configurationClass": "org.apache.camel.component.langchain.embeddings.LangChainEmbeddingsConfiguration", "configurationField": "configuration", "description": "The EmbeddingModel engine to  [...]
     "lazyStartProducer": { "index": 2, "kind": "property", "displayName": "Lazy Start Producer", "group": "producer", "label": "producer", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": false, "description": "Whether the producer should be started lazy (on the first message). By starting lazy you can use this to allow CamelContext and routes to startup in situations where a producer may otherwise fail [...]
     "autowiredEnabled": { "index": 3, "kind": "property", "displayName": "Autowired Enabled", "group": "advanced", "label": "advanced", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": true, "description": "Whether autowiring is enabled. This is used for automatic autowiring options (the option must be marked as autowired) by looking up in the registry to find if there is a single instance of matching t [...]
   },
   "headers": {
-    "CamelLangchainEmbeddingsFinishReason": { "index": 0, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "dev.langchain4j.model.output.FinishReason", "enum": [ "STOP", "LENGTH", "TOOL_EXECUTION", "CONTENT_FILTER", "OTHER" ], "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Finish Reason.", "constantName": "org.apache.camel.component.langchain.embeddings.LangchainEmbeddings$Headers#F [...]
-    "CamelLangchainEmbeddingsInputTokenCount": { "index": 1, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "int", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Input Token Count.", "constantName": "org.apache.camel.component.langchain.embeddings.LangchainEmbeddings$Headers#INPUT_TOKEN_COUNT" },
-    "CamelLangchainEmbeddingsOutputTokenCount": { "index": 2, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "int", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Output Token Count.", "constantName": "org.apache.camel.component.langchain.embeddings.LangchainEmbeddings$Headers#OUTPUT_TOKEN_COUNT" },
-    "CamelLangchainEmbeddingsTotalTokenCount": { "index": 3, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "int", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Total Token Count.", "constantName": "org.apache.camel.component.langchain.embeddings.LangchainEmbeddings$Headers#TOTAL_TOKEN_COUNT" },
-    "CamelLangchainEmbeddingsVector": { "index": 4, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "float[]", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "A dense vector embedding of a text", "constantName": "org.apache.camel.component.langchain.embeddings.LangchainEmbeddings$Headers#VECTOR" }
+    "CamelLangChainEmbeddingsFinishReason": { "index": 0, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "dev.langchain4j.model.output.FinishReason", "enum": [ "STOP", "LENGTH", "TOOL_EXECUTION", "CONTENT_FILTER", "OTHER" ], "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Finish Reason.", "constantName": "org.apache.camel.component.langchain.embeddings.LangChainEmbeddings$Headers#F [...]
+    "CamelLangChainEmbeddingsInputTokenCount": { "index": 1, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "int", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Input Token Count.", "constantName": "org.apache.camel.component.langchain.embeddings.LangChainEmbeddings$Headers#INPUT_TOKEN_COUNT" },
+    "CamelLangChainEmbeddingsOutputTokenCount": { "index": 2, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "int", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Output Token Count.", "constantName": "org.apache.camel.component.langchain.embeddings.LangChainEmbeddings$Headers#OUTPUT_TOKEN_COUNT" },
+    "CamelLangChainEmbeddingsTotalTokenCount": { "index": 3, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "int", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The Total Token Count.", "constantName": "org.apache.camel.component.langchain.embeddings.LangChainEmbeddings$Headers#TOTAL_TOKEN_COUNT" },
+    "CamelLangChainEmbeddingsVector": { "index": 4, "kind": "header", "displayName": "", "group": "producer", "label": "", "required": false, "javaType": "float[]", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "A dense vector embedding of a text", "constantName": "org.apache.camel.component.langchain.embeddings.LangChainEmbeddings$Headers#VECTOR" }
   },
   "properties": {
     "embeddingId": { "index": 0, "kind": "path", "displayName": "Embedding Id", "group": "producer", "label": "", "required": true, "type": "string", "javaType": "java.lang.String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The id" },
-    "embeddingModel": { "index": 1, "kind": "parameter", "displayName": "Embedding Model", "group": "producer", "label": "", "required": true, "type": "object", "javaType": "dev.langchain4j.model.embedding.EmbeddingModel", "deprecated": false, "deprecationNote": "", "autowired": true, "secret": false, "configurationClass": "org.apache.camel.component.langchain.embeddings.LangchainEmbeddingsConfiguration", "configurationField": "configuration", "description": "The EmbeddingModel engine to [...]
+    "embeddingModel": { "index": 1, "kind": "parameter", "displayName": "Embedding Model", "group": "producer", "label": "", "required": true, "type": "object", "javaType": "dev.langchain4j.model.embedding.EmbeddingModel", "deprecated": false, "deprecationNote": "", "autowired": true, "secret": false, "configurationClass": "org.apache.camel.component.langchain.embeddings.LangChainEmbeddingsConfiguration", "configurationField": "configuration", "description": "The EmbeddingModel engine to [...]
     "lazyStartProducer": { "index": 2, "kind": "parameter", "displayName": "Lazy Start Producer", "group": "producer (advanced)", "label": "producer,advanced", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": false, "description": "Whether the producer should be started lazy (on the first message). By starting lazy you can use this to allow CamelContext and routes to startup in situations where a produc [...]
   }
 }
diff --git a/components-starter/camel-langchain-chat-starter/src/main/docs/langchain-chat.json b/components-starter/camel-langchain-chat-starter/src/main/docs/langchain-chat.json
index bff63e792de..535acfbd708 100644
--- a/components-starter/camel-langchain-chat-starter/src/main/docs/langchain-chat.json
+++ b/components-starter/camel-langchain-chat-starter/src/main/docs/langchain-chat.json
@@ -2,13 +2,13 @@
   "groups": [
     {
       "name": "camel.component.langchain-chat",
-      "type": "org.apache.camel.component.chat.springboot.LangchainChatComponentConfiguration",
-      "sourceType": "org.apache.camel.component.chat.springboot.LangchainChatComponentConfiguration"
+      "type": "org.apache.camel.component.chat.springboot.LangChainChatComponentConfiguration",
+      "sourceType": "org.apache.camel.component.chat.springboot.LangChainChatComponentConfiguration"
     },
     {
       "name": "camel.component.langchain-chat.customizer",
       "type": "org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon$CustomizerProperties",
-      "sourceType": "org.apache.camel.component.chat.springboot.LangchainChatComponentConfiguration",
+      "sourceType": "org.apache.camel.component.chat.springboot.LangChainChatComponentConfiguration",
       "sourceMethod": "getCustomizer()"
     }
   ],
@@ -17,26 +17,26 @@
       "name": "camel.component.langchain-chat.autowired-enabled",
       "type": "java.lang.Boolean",
       "description": "Whether autowiring is enabled. This is used for automatic autowiring options (the option must be marked as autowired) by looking up in the registry to find if there is a single instance of matching type, which then gets configured on the component. This can be used for automatic configuring JDBC data sources, JMS connection factories, AWS Clients, etc.",
-      "sourceType": "org.apache.camel.component.chat.springboot.LangchainChatComponentConfiguration",
+      "sourceType": "org.apache.camel.component.chat.springboot.LangChainChatComponentConfiguration",
       "defaultValue": true
     },
     {
       "name": "camel.component.langchain-chat.chat-model",
       "type": "dev.langchain4j.model.chat.ChatLanguageModel",
       "description": "Chat Language Model of type dev.langchain4j.model.chat.ChatLanguageModel. The option is a dev.langchain4j.model.chat.ChatLanguageModel type.",
-      "sourceType": "org.apache.camel.component.chat.springboot.LangchainChatComponentConfiguration"
+      "sourceType": "org.apache.camel.component.chat.springboot.LangChainChatComponentConfiguration"
     },
     {
       "name": "camel.component.langchain-chat.chat-operation",
-      "type": "org.apache.camel.component.chat.LangchainChatOperations",
-      "description": "Operation in case of Endpoint of type CHAT. value is one the values of org.apache.camel.component.langchain.LangchainChatOperations",
-      "sourceType": "org.apache.camel.component.chat.springboot.LangchainChatComponentConfiguration"
+      "type": "org.apache.camel.component.chat.LangChainChatOperations",
+      "description": "Operation in case of Endpoint of type CHAT. The value is one of the values of org.apache.camel.component.langchain.LangChainChatOperations",
+      "sourceType": "org.apache.camel.component.chat.springboot.LangChainChatComponentConfiguration"
     },
     {
       "name": "camel.component.langchain-chat.configuration",
-      "type": "org.apache.camel.component.chat.LangchainChatConfiguration",
-      "description": "The configuration. The option is a org.apache.camel.component.chat.LangchainChatConfiguration type.",
-      "sourceType": "org.apache.camel.component.chat.springboot.LangchainChatComponentConfiguration"
+      "type": "org.apache.camel.component.chat.LangChainChatConfiguration",
+      "description": "The configuration. The option is a org.apache.camel.component.chat.LangChainChatConfiguration type.",
+      "sourceType": "org.apache.camel.component.chat.springboot.LangChainChatComponentConfiguration"
     },
     {
       "name": "camel.component.langchain-chat.customizer.enabled",
@@ -47,13 +47,13 @@
       "name": "camel.component.langchain-chat.enabled",
       "type": "java.lang.Boolean",
       "description": "Whether to enable auto configuration of the langchain-chat component. This is enabled by default.",
-      "sourceType": "org.apache.camel.component.chat.springboot.LangchainChatComponentConfiguration"
+      "sourceType": "org.apache.camel.component.chat.springboot.LangChainChatComponentConfiguration"
     },
     {
       "name": "camel.component.langchain-chat.lazy-start-producer",
       "type": "java.lang.Boolean",
       "description": "Whether the producer should be started lazy (on the first message). By starting lazy you can use this to allow CamelContext and routes to startup in situations where a producer may otherwise fail during starting and cause the route to fail being started. By deferring this startup to be lazy then the startup failure can be handled during routing messages via Camel's routing error handlers. Beware that when the first message is processed then creating and starting the [...]
-      "sourceType": "org.apache.camel.component.chat.springboot.LangchainChatComponentConfiguration",
+      "sourceType": "org.apache.camel.component.chat.springboot.LangChainChatComponentConfiguration",
       "defaultValue": false
     }
   ],
diff --git a/components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangchainChatComponentAutoConfiguration.java b/components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangChainChatComponentAutoConfiguration.java
similarity index 86%
rename from components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangchainChatComponentAutoConfiguration.java
rename to components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangChainChatComponentAutoConfiguration.java
index 86880e8e5d7..876913d16e9 100644
--- a/components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangchainChatComponentAutoConfiguration.java
+++ b/components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangChainChatComponentAutoConfiguration.java
@@ -18,7 +18,7 @@ package org.apache.camel.component.chat.springboot;
 
 import org.apache.camel.CamelContext;
 import org.apache.camel.Component;
-import org.apache.camel.component.chat.LangchainChatComponent;
+import org.apache.camel.component.chat.LangChainChatComponent;
 import org.apache.camel.spi.ComponentCustomizer;
 import org.apache.camel.spring.boot.CamelAutoConfiguration;
 import org.apache.camel.spring.boot.ComponentConfigurationProperties;
@@ -40,25 +40,25 @@ import org.springframework.context.annotation.Lazy;
  */
 @Configuration(proxyBeanMethods = false)
 @Conditional(ConditionalOnCamelContextAndAutoConfigurationBeans.class)
-@EnableConfigurationProperties({ComponentConfigurationProperties.class,LangchainChatComponentConfiguration.class})
+@EnableConfigurationProperties({ComponentConfigurationProperties.class,LangChainChatComponentConfiguration.class})
 @ConditionalOnHierarchicalProperties({"camel.component", "camel.component.langchain-chat"})
-@AutoConfigureAfter({CamelAutoConfiguration.class, LangchainChatComponentConverter.class})
-public class LangchainChatComponentAutoConfiguration {
+@AutoConfigureAfter({CamelAutoConfiguration.class, LangChainChatComponentConverter.class})
+public class LangChainChatComponentAutoConfiguration {
 
     @Autowired
     private ApplicationContext applicationContext;
     private final CamelContext camelContext;
     @Autowired
-    private LangchainChatComponentConfiguration configuration;
+    private LangChainChatComponentConfiguration configuration;
 
-    public LangchainChatComponentAutoConfiguration(
+    public LangChainChatComponentAutoConfiguration(
             org.apache.camel.CamelContext camelContext) {
         this.camelContext = camelContext;
     }
 
     @Lazy
     @Bean
-    public ComponentCustomizer configureLangchainChatComponent() {
+    public ComponentCustomizer configureLangChainChatComponent() {
         return new ComponentCustomizer() {
             @Override
             public void configure(String name, Component target) {
@@ -70,7 +70,7 @@ public class LangchainChatComponentAutoConfiguration {
                         applicationContext,
                         "camel.component.customizer",
                         "camel.component.langchain-chat.customizer")
-                    && target instanceof LangchainChatComponent;
+                    && target instanceof LangChainChatComponent;
             }
         };
     }
diff --git a/components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangchainChatComponentConverter.java b/components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangChainChatComponentConverter.java
similarity index 91%
rename from components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangchainChatComponentConverter.java
rename to components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangChainChatComponentConverter.java
index 6e221ceb6d1..232864ddb58 100644
--- a/components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangchainChatComponentConverter.java
+++ b/components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangChainChatComponentConverter.java
@@ -32,14 +32,14 @@ import org.springframework.stereotype.Component;
 @Configuration(proxyBeanMethods = false)
 @ConfigurationPropertiesBinding
 @Component
-public class LangchainChatComponentConverter implements GenericConverter {
+public class LangChainChatComponentConverter implements GenericConverter {
 
     @Autowired
     private ApplicationContext applicationContext;
 
     public Set<ConvertiblePair> getConvertibleTypes() {
         Set<ConvertiblePair> answer = new LinkedHashSet<>();
-        answer.add(new ConvertiblePair(String.class, org.apache.camel.component.chat.LangchainChatConfiguration.class));
+        answer.add(new ConvertiblePair(String.class, org.apache.camel.component.chat.LangChainChatConfiguration.class));
         answer.add(new ConvertiblePair(String.class, dev.langchain4j.model.chat.ChatLanguageModel.class));
         return answer;
     }
@@ -57,7 +57,7 @@ public class LangchainChatComponentConverter implements GenericConverter {
         }
         ref = ref.startsWith("#bean:") ? ref.substring(6) : ref.substring(1);
         switch (targetType.getName()) {
-            case "org.apache.camel.component.chat.LangchainChatConfiguration": return applicationContext.getBean(ref, org.apache.camel.component.chat.LangchainChatConfiguration.class);
+            case "org.apache.camel.component.chat.LangChainChatConfiguration": return applicationContext.getBean(ref, org.apache.camel.component.chat.LangChainChatConfiguration.class);
             case "dev.langchain4j.model.chat.ChatLanguageModel": return applicationContext.getBean(ref, dev.langchain4j.model.chat.ChatLanguageModel.class);
         }
         return null;
diff --git a/components-starter/camel-langchain-chat-starter/src/main/resources/META-INF/spring/org.springframework.boot.autoconfigure.AutoConfiguration.imports b/components-starter/camel-langchain-chat-starter/src/main/resources/META-INF/spring/org.springframework.boot.autoconfigure.AutoConfiguration.imports
index d9edde7c525..afa2da466a3 100644
--- a/components-starter/camel-langchain-chat-starter/src/main/resources/META-INF/spring/org.springframework.boot.autoconfigure.AutoConfiguration.imports
+++ b/components-starter/camel-langchain-chat-starter/src/main/resources/META-INF/spring/org.springframework.boot.autoconfigure.AutoConfiguration.imports
@@ -17,3 +17,5 @@
 
 org.apache.camel.component.chat.springboot.LangchainChatComponentConverter
 org.apache.camel.component.chat.springboot.LangchainChatComponentAutoConfiguration
+org.apache.camel.component.chat.springboot.LangChainChatComponentConverter
+org.apache.camel.component.chat.springboot.LangChainChatComponentAutoConfiguration
diff --git a/components-starter/camel-langchain-embeddings-starter/src/main/docs/langchain-embeddings.json b/components-starter/camel-langchain-embeddings-starter/src/main/docs/langchain-embeddings.json
index c9c60943858..f18eff801bf 100644
--- a/components-starter/camel-langchain-embeddings-starter/src/main/docs/langchain-embeddings.json
+++ b/components-starter/camel-langchain-embeddings-starter/src/main/docs/langchain-embeddings.json
@@ -2,13 +2,13 @@
   "groups": [
     {
       "name": "camel.component.langchain-embeddings",
-      "type": "org.apache.camel.component.langchain.embeddings.springboot.LangchainEmbeddingsComponentConfiguration",
-      "sourceType": "org.apache.camel.component.langchain.embeddings.springboot.LangchainEmbeddingsComponentConfiguration"
+      "type": "org.apache.camel.component.langchain.embeddings.springboot.LangChainEmbeddingsComponentConfiguration",
+      "sourceType": "org.apache.camel.component.langchain.embeddings.springboot.LangChainEmbeddingsComponentConfiguration"
     },
     {
       "name": "camel.component.langchain-embeddings.customizer",
       "type": "org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon$CustomizerProperties",
-      "sourceType": "org.apache.camel.component.langchain.embeddings.springboot.LangchainEmbeddingsComponentConfiguration",
+      "sourceType": "org.apache.camel.component.langchain.embeddings.springboot.LangChainEmbeddingsComponentConfiguration",
       "sourceMethod": "getCustomizer()"
     }
   ],
@@ -17,14 +17,14 @@
       "name": "camel.component.langchain-embeddings.autowired-enabled",
       "type": "java.lang.Boolean",
       "description": "Whether autowiring is enabled. This is used for automatic autowiring options (the option must be marked as autowired) by looking up in the registry to find if there is a single instance of matching type, which then gets configured on the component. This can be used for automatic configuring JDBC data sources, JMS connection factories, AWS Clients, etc.",
-      "sourceType": "org.apache.camel.component.langchain.embeddings.springboot.LangchainEmbeddingsComponentConfiguration",
+      "sourceType": "org.apache.camel.component.langchain.embeddings.springboot.LangChainEmbeddingsComponentConfiguration",
       "defaultValue": true
     },
     {
       "name": "camel.component.langchain-embeddings.configuration",
-      "type": "org.apache.camel.component.langchain.embeddings.LangchainEmbeddingsConfiguration",
-      "description": "The configuration. The option is a org.apache.camel.component.langchain.embeddings.LangchainEmbeddingsConfiguration type.",
-      "sourceType": "org.apache.camel.component.langchain.embeddings.springboot.LangchainEmbeddingsComponentConfiguration"
+      "type": "org.apache.camel.component.langchain.embeddings.LangChainEmbeddingsConfiguration",
+      "description": "The configuration. The option is a org.apache.camel.component.langchain.embeddings.LangChainEmbeddingsConfiguration type.",
+      "sourceType": "org.apache.camel.component.langchain.embeddings.springboot.LangChainEmbeddingsComponentConfiguration"
     },
     {
       "name": "camel.component.langchain-embeddings.customizer.enabled",
@@ -35,19 +35,19 @@
       "name": "camel.component.langchain-embeddings.embedding-model",
       "type": "dev.langchain4j.model.embedding.EmbeddingModel",
       "description": "The EmbeddingModel engine to use. The option is a dev.langchain4j.model.embedding.EmbeddingModel type.",
-      "sourceType": "org.apache.camel.component.langchain.embeddings.springboot.LangchainEmbeddingsComponentConfiguration"
+      "sourceType": "org.apache.camel.component.langchain.embeddings.springboot.LangChainEmbeddingsComponentConfiguration"
     },
     {
       "name": "camel.component.langchain-embeddings.enabled",
       "type": "java.lang.Boolean",
       "description": "Whether to enable auto configuration of the langchain-embeddings component. This is enabled by default.",
-      "sourceType": "org.apache.camel.component.langchain.embeddings.springboot.LangchainEmbeddingsComponentConfiguration"
+      "sourceType": "org.apache.camel.component.langchain.embeddings.springboot.LangChainEmbeddingsComponentConfiguration"
     },
     {
       "name": "camel.component.langchain-embeddings.lazy-start-producer",
       "type": "java.lang.Boolean",
       "description": "Whether the producer should be started lazy (on the first message). By starting lazy you can use this to allow CamelContext and routes to startup in situations where a producer may otherwise fail during starting and cause the route to fail being started. By deferring this startup to be lazy then the startup failure can be handled during routing messages via Camel's routing error handlers. Beware that when the first message is processed then creating and starting the [...]
-      "sourceType": "org.apache.camel.component.langchain.embeddings.springboot.LangchainEmbeddingsComponentConfiguration",
+      "sourceType": "org.apache.camel.component.langchain.embeddings.springboot.LangChainEmbeddingsComponentConfiguration",
       "defaultValue": false
     }
   ],
diff --git a/components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangchainEmbeddingsComponentAutoConfiguration.java b/components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangChainEmbeddingsComponentAutoConfiguration.java
similarity index 86%
rename from components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangchainEmbeddingsComponentAutoConfiguration.java
rename to components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangChainEmbeddingsComponentAutoConfiguration.java
index 0f276a412e2..15039ce2a3b 100644
--- a/components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangchainEmbeddingsComponentAutoConfiguration.java
+++ b/components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangChainEmbeddingsComponentAutoConfiguration.java
@@ -18,7 +18,7 @@ package org.apache.camel.component.langchain.embeddings.springboot;
 
 import org.apache.camel.CamelContext;
 import org.apache.camel.Component;
-import org.apache.camel.component.langchain.embeddings.LangchainEmbeddingsComponent;
+import org.apache.camel.component.langchain.embeddings.LangChainEmbeddingsComponent;
 import org.apache.camel.spi.ComponentCustomizer;
 import org.apache.camel.spring.boot.CamelAutoConfiguration;
 import org.apache.camel.spring.boot.ComponentConfigurationProperties;
@@ -40,25 +40,25 @@ import org.springframework.context.annotation.Lazy;
  */
 @Configuration(proxyBeanMethods = false)
 @Conditional(ConditionalOnCamelContextAndAutoConfigurationBeans.class)
-@EnableConfigurationProperties({ComponentConfigurationProperties.class,LangchainEmbeddingsComponentConfiguration.class})
+@EnableConfigurationProperties({ComponentConfigurationProperties.class,LangChainEmbeddingsComponentConfiguration.class})
 @ConditionalOnHierarchicalProperties({"camel.component", "camel.component.langchain-embeddings"})
-@AutoConfigureAfter({CamelAutoConfiguration.class, LangchainEmbeddingsComponentConverter.class})
-public class LangchainEmbeddingsComponentAutoConfiguration {
+@AutoConfigureAfter({CamelAutoConfiguration.class, LangChainEmbeddingsComponentConverter.class})
+public class LangChainEmbeddingsComponentAutoConfiguration {
 
     @Autowired
     private ApplicationContext applicationContext;
     private final CamelContext camelContext;
     @Autowired
-    private LangchainEmbeddingsComponentConfiguration configuration;
+    private LangChainEmbeddingsComponentConfiguration configuration;
 
-    public LangchainEmbeddingsComponentAutoConfiguration(
+    public LangChainEmbeddingsComponentAutoConfiguration(
             org.apache.camel.CamelContext camelContext) {
         this.camelContext = camelContext;
     }
 
     @Lazy
     @Bean
-    public ComponentCustomizer configureLangchainEmbeddingsComponent() {
+    public ComponentCustomizer configureLangChainEmbeddingsComponent() {
         return new ComponentCustomizer() {
             @Override
             public void configure(String name, Component target) {
@@ -70,7 +70,7 @@ public class LangchainEmbeddingsComponentAutoConfiguration {
                         applicationContext,
                         "camel.component.customizer",
                         "camel.component.langchain-embeddings.customizer")
-                    && target instanceof LangchainEmbeddingsComponent;
+                    && target instanceof LangChainEmbeddingsComponent;
             }
         };
     }
diff --git a/components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangchainEmbeddingsComponentConfiguration.java b/components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangChainEmbeddingsComponentConfiguration.java
similarity index 90%
rename from components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangchainEmbeddingsComponentConfiguration.java
rename to components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangChainEmbeddingsComponentConfiguration.java
index 7bd080d044b..423513d5d11 100644
--- a/components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangchainEmbeddingsComponentConfiguration.java
+++ b/components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangChainEmbeddingsComponentConfiguration.java
@@ -17,17 +17,17 @@
 package org.apache.camel.component.langchain.embeddings.springboot;
 
 import dev.langchain4j.model.embedding.EmbeddingModel;
-import org.apache.camel.component.langchain.embeddings.LangchainEmbeddingsConfiguration;
+import org.apache.camel.component.langchain.embeddings.LangChainEmbeddingsConfiguration;
 import org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon;
 import org.springframework.boot.context.properties.ConfigurationProperties;
 
 /**
- * Langchain4j Embeddings
+ * LangChain4j Embeddings
  * 
  * Generated by camel-package-maven-plugin - do not edit this file!
  */
 @ConfigurationProperties(prefix = "camel.component.langchain-embeddings")
-public class LangchainEmbeddingsComponentConfiguration
+public class LangChainEmbeddingsComponentConfiguration
         extends
             ComponentConfigurationPropertiesCommon {
 
@@ -38,9 +38,9 @@ public class LangchainEmbeddingsComponentConfiguration
     private Boolean enabled;
     /**
      * The configuration. The option is a
-     * org.apache.camel.component.langchain.embeddings.LangchainEmbeddingsConfiguration type.
+     * org.apache.camel.component.langchain.embeddings.LangChainEmbeddingsConfiguration type.
      */
-    private LangchainEmbeddingsConfiguration configuration;
+    private LangChainEmbeddingsConfiguration configuration;
     /**
      * The EmbeddingModel engine to use. The option is a
      * dev.langchain4j.model.embedding.EmbeddingModel type.
@@ -67,11 +67,11 @@ public class LangchainEmbeddingsComponentConfiguration
      */
     private Boolean autowiredEnabled = true;
 
-    public LangchainEmbeddingsConfiguration getConfiguration() {
+    public LangChainEmbeddingsConfiguration getConfiguration() {
         return configuration;
     }
 
-    public void setConfiguration(LangchainEmbeddingsConfiguration configuration) {
+    public void setConfiguration(LangChainEmbeddingsConfiguration configuration) {
         this.configuration = configuration;
     }
 
diff --git a/components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangchainEmbeddingsComponentConverter.java b/components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangChainEmbeddingsComponentConverter.java
similarity index 92%
rename from components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangchainEmbeddingsComponentConverter.java
rename to components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangChainEmbeddingsComponentConverter.java
index 84d0f7938dc..505ac5e2be0 100644
--- a/components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangchainEmbeddingsComponentConverter.java
+++ b/components-starter/camel-langchain-embeddings-starter/src/main/java/org/apache/camel/component/langchain/embeddings/springboot/LangChainEmbeddingsComponentConverter.java
@@ -32,7 +32,7 @@ import org.springframework.stereotype.Component;
 @Configuration(proxyBeanMethods = false)
 @ConfigurationPropertiesBinding
 @Component
-public class LangchainEmbeddingsComponentConverter
+public class LangChainEmbeddingsComponentConverter
         implements
             GenericConverter {
 
@@ -41,7 +41,7 @@ public class LangchainEmbeddingsComponentConverter
 
     public Set<ConvertiblePair> getConvertibleTypes() {
         Set<ConvertiblePair> answer = new LinkedHashSet<>();
-        answer.add(new ConvertiblePair(String.class, org.apache.camel.component.langchain.embeddings.LangchainEmbeddingsConfiguration.class));
+        answer.add(new ConvertiblePair(String.class, org.apache.camel.component.langchain.embeddings.LangChainEmbeddingsConfiguration.class));
         answer.add(new ConvertiblePair(String.class, dev.langchain4j.model.embedding.EmbeddingModel.class));
         return answer;
     }
@@ -59,7 +59,7 @@ public class LangchainEmbeddingsComponentConverter
         }
         ref = ref.startsWith("#bean:") ? ref.substring(6) : ref.substring(1);
         switch (targetType.getName()) {
-            case "org.apache.camel.component.langchain.embeddings.LangchainEmbeddingsConfiguration": return applicationContext.getBean(ref, org.apache.camel.component.langchain.embeddings.LangchainEmbeddingsConfiguration.class);
+            case "org.apache.camel.component.langchain.embeddings.LangChainEmbeddingsConfiguration": return applicationContext.getBean(ref, org.apache.camel.component.langchain.embeddings.LangChainEmbeddingsConfiguration.class);
             case "dev.langchain4j.model.embedding.EmbeddingModel": return applicationContext.getBean(ref, dev.langchain4j.model.embedding.EmbeddingModel.class);
         }
         return null;
diff --git a/components-starter/camel-langchain-embeddings-starter/src/main/resources/META-INF/spring/org.springframework.boot.autoconfigure.AutoConfiguration.imports b/components-starter/camel-langchain-embeddings-starter/src/main/resources/META-INF/spring/org.springframework.boot.autoconfigure.AutoConfiguration.imports
index 1ada5a361f5..eb9e02b8085 100644
--- a/components-starter/camel-langchain-embeddings-starter/src/main/resources/META-INF/spring/org.springframework.boot.autoconfigure.AutoConfiguration.imports
+++ b/components-starter/camel-langchain-embeddings-starter/src/main/resources/META-INF/spring/org.springframework.boot.autoconfigure.AutoConfiguration.imports
@@ -17,3 +17,5 @@
 
 org.apache.camel.component.langchain.embeddings.springboot.LangchainEmbeddingsComponentConverter
 org.apache.camel.component.langchain.embeddings.springboot.LangchainEmbeddingsComponentAutoConfiguration
+org.apache.camel.component.langchain.embeddings.springboot.LangChainEmbeddingsComponentConverter
+org.apache.camel.component.langchain.embeddings.springboot.LangChainEmbeddingsComponentAutoConfiguration
diff --git a/components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangchainChatComponentConfiguration.java b/components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangChainChatComponentConfiguration.java
similarity index 81%
rename from components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangchainChatComponentConfiguration.java
rename to components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangChainChatComponentConfiguration.java
index 547171c03b3..d14f7785a9f 100644
--- a/components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangchainChatComponentConfiguration.java
+++ b/components-starter/camel-langchain-chat-starter/src/main/java/org/apache/camel/component/chat/springboot/LangChainChatComponentConfiguration.java
@@ -17,19 +17,19 @@
 package org.apache.camel.component.chat.springboot;
 
 import dev.langchain4j.model.chat.ChatLanguageModel;
-import org.apache.camel.component.chat.LangchainChatComponent;
-import org.apache.camel.component.chat.LangchainChatConfiguration;
-import org.apache.camel.component.chat.LangchainChatOperations;
+import org.apache.camel.component.chat.LangChainChatComponent;
+import org.apache.camel.component.chat.LangChainChatConfiguration;
+import org.apache.camel.component.chat.LangChainChatOperations;
 import org.apache.camel.spring.boot.ComponentConfigurationPropertiesCommon;
 import org.springframework.boot.context.properties.ConfigurationProperties;
 
 /**
- * Langchain4j Chat component
+ * LangChain4j Chat component
  * 
  * Generated by camel-package-maven-plugin - do not edit this file!
  */
 @ConfigurationProperties(prefix = "camel.component.langchain-chat")
-public class LangchainChatComponentConfiguration
+public class LangChainChatComponentConfiguration
         extends
             ComponentConfigurationPropertiesCommon {
 
@@ -39,15 +39,15 @@ public class LangchainChatComponentConfiguration
      */
     private Boolean enabled;
     /**
      * Operation in case of Endpoint of type CHAT. value is one the values of
      * org.apache.camel.component.langchain.LangchainChatOperations
      */
-    private LangchainChatOperations chatOperation = LangchainChatOperations.CHAT_SINGLE_MESSAGE;
+    private LangChainChatOperations chatOperation = LangChainChatOperations.CHAT_SINGLE_MESSAGE;
     /**
      * The configuration. The option is a
-     * org.apache.camel.component.chat.LangchainChatConfiguration type.
+     * org.apache.camel.component.chat.LangChainChatConfiguration type.
      */
-    private LangchainChatConfiguration configuration;
+    private LangChainChatConfiguration configuration;
     /**
      * Whether the producer should be started lazy (on the first message). By
      * starting lazy you can use this to allow CamelContext and routes to
@@ -74,19 +74,19 @@ public class LangchainChatComponentConfiguration
      */
     private ChatLanguageModel chatModel;
 
-    public LangchainChatOperations getChatOperation() {
+    public LangChainChatOperations getChatOperation() {
         return chatOperation;
     }
 
-    public void setChatOperation(LangchainChatOperations chatOperation) {
+    public void setChatOperation(LangChainChatOperations chatOperation) {
         this.chatOperation = chatOperation;
     }
 
-    public LangchainChatConfiguration getConfiguration() {
+    public LangChainChatConfiguration getConfiguration() {
         return configuration;
     }
 
-    public void setConfiguration(LangchainChatConfiguration configuration) {
+    public void setConfiguration(LangChainChatConfiguration configuration) {
         this.configuration = configuration;
     }
 
@@ -39,15 +39,15 @@ public class LangchainChatComponentConfiguration
     private Boolean enabled;
     /**
-     * Operation in case of Endpoint of type CHAT. value is one the values of
-     * org.apache.camel.component.langchain.LangchainChatOperations
+     * Operation in case of Endpoint of type CHAT. The value is one of the
+     * values of org.apache.camel.component.langchain.LangChainChatOperations
      */